Guess
=====
.. module:: guessit.guess

.. autoclass:: Guess
    :members:

.. autofunction:: choose_int
.. autofunction:: choose_string
.. autofunction:: merge_similar_guesses
.. autofunction:: merge_all
